#! /bin/sh
#
#  format_mount.sh

# Find other linux partitions, ignore swap.
# Again, a better way would be useful.

export BOOT_IS_DEVICE

if [ "$method" = "iso" ] || [ "$method" = "rpms" ]; then
    avail_part=`fdisk -l | grep  Linux | grep -v swap |\
    grep -v ${iso_part} | cut -d / -f 3 | cut -c 1-5`
else
    avail_part=`fdisk -l | grep  Linux | grep -v swap |\
    cut -d / -f 3 | cut -c 1-5`
fi

echo Available partitions = $avail_part >> $install_log
echo

# Log the output of fdisk so we have a record for troubleshooting.
echo >> $install_log
echo "############# FDISK OUTPUT ###############" >> $install_log
/sbin/fdisk -l >> $install_log
echo >> $install_log
echo "########### END FDISK OUTPUT #############" >> $install_log
echo >> $install_log

# Explicitly create the '/' partition. The user can create other mount
# points, but we need to be sure we have '/'.
valid=0
while [ "$valid" -eq "0" ]
do
    # If not defined in the config file ask.

    if [ -z "$ROOT_PART" ]; then
	dialog --inputbox "
    Which partition shall become your new '/' filesystem.

    Available partitions are: [ `echo $avail_part` ]
" 12 70 '' 2>/tmp/dialog.inp
	ROOT_PART=`cat /tmp/dialog.inp`
    fi

    # In all cases, do a sanity check.
    echo ROOT_PART_SELECTED=$ROOT_PART >> $install_log
    if [ -z "$ROOT_PART" ]; then
	dialog --msgbox '
    You did not choose a root partition!
' 12 70
	continue
    fi

    if [ "/dev/$ROOT_PART" = "$INSTALL_DEV" ]; then
	dialog --msgbox "
    You selected the entire device $ROOT_PART
    You should select a single partition instead.
" 12 70
	continue
    fi
    if [ "$ROOT_PART" = "/dev/" ]; then
	dialog --msgbox '
    Hrmm, I ended up with /dev/ as your root partition.
    That s not good.
' 12 70
	continue
    fi

    echo $avail_part | grep -q $ROOT_PART 2> /dev/null

    if [ $? -ne 0 ] ; then
	dialog --msgbox "
   Partition [ $ROOT_PART ] isn't a valid entry
   within available partitions [ $avail_part ].
" 12 70
	valid=0
	# Avoid a loop due to a bad config file define.
	ROOT_PART=
    else
	valid=1
	ROOT_DEV=/dev/$ROOT_PART
	export ROOT_PART ROOT_DEV
	echo ROOT_DEV=$ROOT_DEV >> $install_log
    fi
    abort=0
done

# Format the root file system.
if [ -z "$SKIP_FORMAT_ROOT" ]; then
    dialog --defaultno --colors --yesno "
    It is suggested that you format the root filesystem.
\\Z1    
                     *************
                     * Attention *
                     *************

    Formatting erases contents of this partition, no way
    to get it back later.
\\Zn
    Format <${ROOT_DEV}> type <$fstype> now ?
" 15 70
[ $? -eq 0 ] && answer=yes || answer=no

    if [ "$answer" = "yes" ]; then
	echo "Creating root file system."
	mke2fs ${fsopts} ${ROOT_DEV} > /dev/null 2>&1 || {
	    echo "Failed to create file system, exiting." | tee -a $install_log
	    echo "Turning off swap."
	    for device in $SWAP_DEV
	    do
		swapoff "$device"
		break
	    done
        }
	echo "Done."
	sleep 3
    fi
else
    if [ "$SKIP_FORMAT_ROOT" -eq "0" ]; then
	echo "Creating root file system."
	mke2fs ${fsopts} ${ROOT_DEV} > /dev/null 2>&1 || {
	    echo "Failed to create file system, exiting." | tee -a $install_log
	    echo "Turning off swap."
	    for device in $SWAP_DEV
	    do
		swapoff "$device"
		break
	    done
	}
	echo "Done."
    fi
fi

# Mount the root filesystem.
echo "Mounting the root partition $ROOT_DEV on '/newroot'."
mount | grep /newroot || mount "$ROOT_DEV" /newroot/ 2>&1 || {
    echo "Failed to mount the root filesystem, exiting." | tee -a $install_log
    echo "Turning off swap."
    for device in $SWAP_DEV
    do
	swapoff $device
    done
}
sleep 3

# Remove the root device from the list of available devices.
avail_part=`echo $avail_part | sed 's/'$ROOT_PART'//'`

#Check for another available partition.
if [ -n "$avail_part" ] ; then
    dialog --msgbox "
    The following partitions are also available for use:

    [ `echo $avail_part` ]

    You may select mount points for each. Those not selected
    will not be formatted or mounted during installation.
" 12 70
    
    for part in $avail_part
    do
	dialog --inputbox "
    Enter a mount point for [ /dev/$part ]
    For example: boot, var, usr, home.

    If you dont want to format and mount this partition do not
    input anything.  Just press ENTER.
" 20 70	'' 2>/tmp/dialog.inp
	mount_point=`cat /tmp/dialog.inp`
	[ "$mount_point" = 'boot' ] && { BOOT_IS_DEVICE=yes; echo BOOT_IS_DEVICE=$BOOT_IS_DEVICE, press ENTER; read x; }
	if [ -n "$mount_point" ] ; then
	    MOUNTS="$MOUNTS $mount_point"
	    echo "/dev/$part will be mounted as $mount_point." | tee -a $install_log
	    dialog --defaultno --colors --yesno "
    It is suggested that you format the root filesystem.
\\Z1    
                     *************
                     * Attention *
                     *************

    Formatting erases contents of this partition, no way
    to get it back later.
\\Zn
    Format [ /dev/$part ] type <$fstype> now ?
" 15 70
	    [ $? -eq 0 ] && answer=yes || answer=no
	    if [ "$answer" = "yes" ]; then
		echo "Creating filesystem."
		mke2fs ${fsopts} /dev/$part > /dev/null 2>&1 || {
		    echo "Failed to create file system on /dev/$part, exiting." | tee -a $install_log
		    sleep 5
		    echo "Turning off swap."
		    for device in $SWAP_DEV
		    do
			swapoff $device
		    done
		    umount $ROOT_DEV
		    umount -a
		    break
		}
	    echo "Done."
	    sleep 3
        fi
        echo "Mounting /dev/$part on '/newroot/$mount_point'."
        mkdir -p /newroot/$mount_point
        mount /dev/$part /newroot/$mount_point > /dev/null 2>&1 || {
	    echo "Failed to mount the $mount_point filesystem." | tee -a $install_log
            sleep 5
	    echo "Turning off swap."
	    for device in $SWAP_DEV
	    do
		swapoff $device
	    done
	    umount $ROOT_DEV
	    umount -a
	    break
        }
        echo "Done."
        echo "/dev/$part      $mount_point          $fstype    defaults      1 2" >> fstab
        avail_part=`echo $avail_part | sed 's/'$part'//'`
    fi
    done
    echo Mount points=$MOUNTS >> $install_log
fi
export MOUNTS

# echo press ENTER; read x