#! /bin/sh
#
#  grub_install.sh

echo Preparing to install GRUB
# Get the kernel and initrd names
# kernel_name=`ls /boot/|grep vmlinuz-`
kernel_name=vmlinuz-2.6.9-1.667
kernel_version=`echo $kernel_name | cut -d - -f 2,3`
# initrd_name=`ls /boot/|grep initrd-`
initrd_name=initrd-2.6.9-1.667.img
if [ $? -ne 0 ] ; then
    initrd_name=
fi

# Create grub.conf. We don't install grub by default, though.
# Device numbers are not currently handled at all. (0,1) for example.

# Create the directory for grub
[ ! -d /boot/grub ] && mkdir -p /boot/grub

GRUB=/boot/grub/grub.conf
bootprefix=/boot
[ "$BOOT_IS_DEVICE" = 'yes' ] && bootprefix=''

cat >$GRUB <<EOF
# File generated by the RULE 'Slinky' installer.
# You do not have to rerun grub after making changes to this file
# NOTICE:  If you have a /boot partition, all kernel and
#          initrd paths are relative to /boot/, eg.
#          root (hd1,0)
#          kernel /vmlinuz-version root=/dev/hdb7 ro
#          initrd /initrd-version.img
# boot=$INSTALL_DEV
# boot=(hd0,0)
default=saved
timeout=60
# splashimage=(hd0,1)/grub/splash.xpm.gz
title Fedora FC$version ($kernel_version)
#        root (hd0,0)
kernel $bootprefix/$kernel_name root=$ROOT_DEV ro
EOF

if [ -n "$initrd_name" ] ; then
    echo "initrd $bootprefix/$initrd_name" >> $GRUB
fi

dialog --yesno '
    Do you want to add the installation kernel from SLINKY
    to the boot options of your new system?  This could be
    usefull if you have too less memory to boot the regular
    kernel of FC3.
' 12 70
[ $? -eq 0 ] && answer=yes || answer=no
if [ "$answer" = 'yes' ]; then
    while :; do
	echo Insert SLINKY boot-floppy, press ENTER; read x
	mount -t msdos /dev/fd0 /mnt/floppy && break
    done
    cp /mnt/floppy/vmlinuz /boot/vmlinuz-2.6.11.12 || {
	echo copying /mnt/floppy/vmlinuz to /boot/vmlinuz-2.6.11.12 failed
    }
    umount /mnt/floppy

    # add the small Kernel from the SLINKY boot-disk
    # but use the initrd from FC3
    cat >>$GRUB <<EOF
# Kernel from SLINKY installation in case the FC3-Kernel is too big
title Small Kernel from SLINKY boot-disk (2.6.11.12)
kernel $bootprefix/vmlinuz-2.6.11.12 root=$ROOT_DEV ro
EOF
    if [ -n "$initrd_name" ] ; then
	echo "initrd $bootprefix/$initrd_name" >> $GRUB
    fi
fi

dialog --defaultno --yesno "
    Shall I install GRUB on $INSTALL_DEV ?

    This will overwrite the masterboot record of $INSTALL_DEV.
    If you have installed also other operating systems, they
    might not boot any more.  (Thou it is possible to configure
    GRUB later in a way to also boot these systems).

    If you are unshure, select 'NO' here but create a boot floppy
    later.
" 15 70
[ $? -eq 0 ] && answer=yes || answer=no
    
if [ "$answer" = "yes" ]; then
    echo grub-install "$INSTALL_DEV" >>$install_log
    grub-install $INSTALL_DEV || {
        echo "OOPS! GRUB didn't install properly!"
	echo "You should fix that before continuing."
	echo "If you want to try to fix GRUB, enter"
	echo "Alt-F2 for a new shell, edit $GRUB"
	echo "and rerun: grub-install $INSTALL_DEV"
	echo "You can then return here (Alt-F1)"
	echo "and hit ENTER to continue."
	echo -n "ENTER to continue. :"
	read answer
    }
else
   echo "GRUB installation skipped by user." | tee -a $install_log
   echo "Be sure to create a boot disk when prompted!"
fi


# ## # Create /etc/lilo.conf
# ## LILO=/etc/lilo.conf
# ## 
# ## cat<<EOF > $LILO
# ## prompt
# ## timeout=50
# ## default=linux
# ## boot=$INSTALL_DEV
# ## map=/boot/map
# ## install=/boot/boot.b
# ## # message=/boot/message
# ## lba32
# ## 
# ## image=/boot/$kernel_name
# ##     label=linux
# ## EOF
# ## if [ -n "$initrd_name" ] ; then
# ##     echo "   initrd=/boot/$initrd_name" >> $LILO
# ## fi
# ## echo "    read-only" >> $LILO
# ## echo "    root=$ROOT_DEV" >> $LILO 
# ## 
# ## echo >> $install_log
# ## echo "Contents of /etc/lilo.conf" >> $install_log
# ## echo >> $install_log
# ## echo "######### BEGIN LILO.CONF ######################" >> $install_log
# ## echo >> $install_log
# ## cat /etc/lilo.conf >> $install_log
# ## echo "########## END LILO.CONF #######################" >> $install_log
# ## echo >> $install_log
# ## 
# ## cat<<EOF
# ## 
# ##           ##### *****     IMPORTANT     ***** #####
# ## 
# ##      You have the option of installing lilo on the master
# ##      boot record of $INSTALL_DEV. If you elect not to install
# ##      lilo, you must create a boot disk, or you will be unable
# ##      to boot your new Linux install. You will be asked to
# ##      create a boot disk next, in either case.
# ## 
# ##      If there is another operating system installed on this
# ##      machine, say 'NO' here, unless you know what you are
# ##      doing. If, for example, you have an existing Windows(R)
# ##      install, then /etc/lilo.conf must be modified (and
# ##      "/sbin/lilo" re-run) or you may not be able to dual boot.
# ## 
# ## EOF
# ## 
# ## echo -n "Shall I install lilo on $INSTALL_DEV ? [yes / NO]: "
# ## read answer
# ##     
# ## if [ "$answer" = "yes" ]; then
# ##     lilo -v -C /etc/lilo.conf | tee -a $install_log || {
# ##     
# ##     echo "OOPS! Lilo didn't install properly!"
# ##     echo "You should fix that before continuing."
# ##     echo "You should at least choose to make a"
# ##     echo "boot disk when you are prompted to do so."
# ##     echo "If you want to try to fix lilo, enter"
# ##     echo "Alt-F2 for a new shell, edit /etc/lilo.conf"
# ##     echo "and rerun 'lilo -v -C /etc/lilo.conf'"
# ##     echo "You can then return here (Alt-F1)"
# ##     echo "and hit ENTER to continue."
# ##     echo -n "ENTER to continue. :"
# ##     read answer
# ##     }
# ## else
# ##    echo "Lilo installation skipped by user." | tee -a $install_log
# ##    echo "Be sure to create a boot disk when prompted!"
# ## fi
