#! /bin/sh
#
#  mount_installsource.sh

# In /newroot context:
# Prepare the source of installation for the packages contained on
# Fedora disc1
# For ISOs 1) mount the (local/nfs)-partition on /mnt/loop
#          2) mount loop the iso on /mnt/cdrom
# For rpms: 1) mount the (local/nfs)-partition on /mnt/cdrom
# ftp doesn't need mounting, the rpms are transferes with busybox-ftpget


# Bit of a hack, but we need access to the old
# /proc  directory for a while yet.
# Also the link to the mounted loop device for image installs.
[ ! -e /proc ] && ln -s /oldroot/proc /proc

[ ! -d /mnt/cdrom ] && mkdir -p /mnt/cdrom
[ ! -d /mnt/loop  ] && mkdir -p /mnt/loop

case "$method" in
'nfsrpms')
    # ln -s /oldroot/mnt/cdrom /mnt/cdrom
    mount -t nfs -o ro,nolock ${exportedfs} /mnt/cdrom 2>&1  || {
	echo
	echo "Failed to mount ${exportedfs} on /mnt/cdrom" | tee -a $install_log
	echo "Mount failed, switch to another terminal and try mounting manually:"
	echo "mount -t nfs -o ro,nolock <$exportedfs> /mnt/cdrom"
	echo "Then return here and press ENTER to continue."
	read answer
    }
    ;;

'nfsiso')
    # ln -s /oldroot/mnt/cdrom /mnt/cdrom
    mount -t nfs -o ro,nolock ${exportedfs} /mnt/loop 2>&1  || {
	echo
	echo "Failed to mount ${exportedfs} on /mnt/loop" | tee -a $install_log
	echo "Mount failed, switch to another terminal and try mounting manually:"
	echo "mount -t nfs -o ro,nolock <$exportedfs> /mnt/loop"
	echo "Then return here and press ENTER to continue."
	read answer
    }
    mount -o loop -t iso9660 /mnt/loop/${iso_file} /mnt/cdrom || {
	echo
	echo "Failed to mount /mnt/loop/${iso_file}." | tee -a $install_log
	echo "Mount failed, switch to another terminal and try mounting manually:"
	echo "mount -o loop -t iso9660 /mnt/loop/${iso_file} /mnt/cdrom"
	echo "Then return here and press ENTER to continue."
	read answer
    }
    ;;

'iso')
    # If we are doing an iso install, get the first iso mounted.
    mount /dev/${iso_part} /mnt/loop || {
	echo
	echo "Failed to mount /dev/${iso_part} on /mnt/loop" | tee -a $install_log
	echo "Mount failed, switch to another terminal and try mounting manually:"
	echo "mount /dev/${iso_part} /mnt/loop"
	echo "Then return here and press ENTER to continue."
	read answer
    }
    mount -o loop -t iso9660 /mnt/loop/${iso_file} /mnt/cdrom || {
	echo
	echo "Failed to mount /mnt/loop/${iso_file}." | tee -a $install_log
	echo "Mount failed, switch to another terminal and try mounting manually:"
	echo "mount -o loop -t iso9660 /mnt/loop/${iso_file} /mnt/cdrom"
	echo "Then return here and press ENTER to continue."
	read answer
    }
    ;;

'rpms')
    # If we are doing an rpm hard drive install, get the filesystem mounted.
    mount /dev/${iso_part} /mnt/cdrom || {
	echo
	echo "Failed to mount /dev/${iso_part}." | tee -a $install_log
	echo "Mount failed, switch to another terminal and try mounting manually:"
	echo "mount /dev/${iso_part} /mnt/cdrom"
	echo "Then return here and press ENTER to continue."
	read answer
    }
    ;;

'cdrom')
    # If we have a cdrom, mount disc1 here.
    dialog --msgbox "
    Please insert ${distri} Core ${version} disc1 in your cd drive.
    Press ENTER when ready.
" 12 70
    loop=yes
    while [ "$loop" = 'yes' ]; do
	loop=no
	echo "Mounting $CDROM_DEV on /mnt/cdrom"
	mount -t iso9660 -o ro $CDROM_DEV /mnt/cdrom
	if [ "$?" != '0' ]; then
	    dialog --no-label 'MANUAL MOUNT' --yesno "
    Mounting $CDROM_DEV on /mnt/cdrom failed.
    You can try mounting manually from the other console with:

    mount -t iso9660 $CDROM_DEV /mnt/cdrom

    Then return here and select 'MANUAL MOUNT' to continue.

    Or check the CD and select 'YES' to try the mount again.
" 15 70
	    [ $? -eq 0 ] && loop=yes || loop=no
	fi
    done
    ;;
esac
