#!/bin/sh

# create SLINKY boot-floppy

# set -x

source version.h

image=${version}-disk1.img

trap "echo unmounting bootdisk1 from loop; umount `pwd`/${image}" 0

echo
echo "Creating boot disk ${image}."

rm rootfs*
echo "Creating new rootfs"
dd if=/dev/zero of=rootfs bs=1k count=2048 || {
    echo "Error while creating filesystem, exiting."
    exit
}

mkfs.ext2 -F -m 0 -N 550 -b 1024 rootfs || {
    echo "Error while making ext2 filesystem, exiting."
    exit
}

echo "Mounting rootfs on the loop device."
rm -rf loop
mkdir loop
mount -o loop rootfs loop/ || {
    echo "Error mounting filesystem, exiting."
    exit
}

mount

rm -Rf loop/lost+found
echo "Copying filesystem."
# cp -a filesystem/* loop || {
#     echo "Error copying filesystem, exiting."
#     exit
# }

cd filesystem
find . -depth -print | grep -v CVS | cpio -pdmu ../loop
cd -

# find loop -depth -exec touch -d "20040101" {} \;
echo that\'s loop now:
ls -l loop
df -k
echo hit  RETURN

echo "Unmounting loop filesystem."
umount loop || {
    echo "Error unmounting loop filesystem, exiting."
    exit
}
echo "Gzipping root file system."
gzip -9 rootfs

echo "Creating ${image}"
dd if=/dev/zero of=${image} bs=1k count=1440

echo "Formatting ${image}."
mkdosfs -r 16 -C ${image} 1440 || {
    echo "Error formatting the floppy image, exiting."
    exit
}

echo "Running syslinux."
syslinux ${image} || {
    echo "Error running syslinux, exiting."
    exit
}

echo "Mounting ${image} on the loop device."
mount -o loop -t msdos ${image} loop || {
    echo "Error mounting filesystem, exiting."
    exit
}

echo "Copying files."
cp base_files/syslinux.cfg loop
sed -e "s/IK_VERSION/${ik_version}/" -e "s/VERSION/${version}/" base_files/boot.msg > loop/boot.msg
sed -e "s/IK_VERSION/${ik_version}/" -e "s/VERSION/${version}/" base_files/boot2.msg > loop/boot2.msg
cp base_files/col9.msg loop
# cp base_files/col0.msg loop
# cp base_files/rule.lss loop
# cp base_files/sample.msg loop
cp base_files/rulelogo.lss loop
# cp base_files/tuxsmall.lss loop

echo "Copying rootfs.gz."
cp rootfs.gz loop

echo "Copying the kernel."
cp base_files/vmlinuz-rule loop/vmlinuz

du -sk loop/*
df -k loop
ls -l rootfs.gz

echo
echo If there is no space left in the slinky-img \(column Available = 0\)
echo the installation will not work. Repeat this script, the size of
echo rootfs.gz might surprisingly change slightly.
echo press ENTER; read x

echo "Unmounting loop filesystem."
umount loop || {
    echo "Error unmounting loop filesystem, exiting."
    exit
}

echo "Moving ${image} to slinky directory."
mkdir -p slinky-images/${version}
mv ${image} slinky-images/${version} || {
    echo "Error moving ${image}."
    exit
}
rm -f rootfs.gz
# mount

echo create a floppy with: dd if=slinky-images/${version}/${image} of=/dev/fd0 bs=512
dd if=slinky-images/${version}/${image} of=/dev/fd0 bs=512
echo
echo "Done."
exit

